#!/bin/sh

LOG_FILE="/var/log/syslog.log"
CURRENT_USER=`echo $USER`
GLOBAL_CMD_ECHO=""

exitWithPrintErrorLog()
{
    local date=`date '+%Y-%m-%d %H:%M:%S'`
    echo "[$date][ULTRAPATH][${CURRENT_USER}][ERROR][upCheckUnTakeOverDisk] The \"$1\" command fails to be executed." >> "${LOG_FILE}"
    exit 2
}

executeCmdAndGetEcho()
{
    GLOBAL_CMD_ECHO=`$1 2>/dev/null`
    local ret=$? 
    if [ ${ret} -ne 0 ] 
    then
        exitWithPrintErrorLog "$1"
    fi
    return 0
}
checkRedundantDisk()
{
    local claimRule_str=""
    local diskSet=""
    local thisVendor=""
    local thisModel=""
    executeCmdAndGetEcho "esxcli storage core claimrule list"
    claimRule_str="${GLOBAL_CMD_ECHO}"
    executeCmdAndGetEcho "esxcli storage core device list"
    diskSet=`echo "${GLOBAL_CMD_ECHO}" |grep -E "^naa"`
    for i in $diskSet;do
        i=`echo ${i} | sed -e 's/://g'`
        executeCmdAndGetEcho "esxcli storage core device list -d $i"
        if [ `echo "${GLOBAL_CMD_ECHO}" |grep -E -c "\<Multipath Plugin: MP_PLUGIN_ULTRAPATH\>"` -eq 0 ]
        then
            thisVendor=`echo "${GLOBAL_CMD_ECHO}" |grep "Vendor" |awk -F ":" '{print $2}' |sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
            thisModel=`echo "${GLOBAL_CMD_ECHO}" |grep "Model" |awk -F ":" '{print $2}' |sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
            if [ `echo "${claimRule_str}" | grep "runtime"| grep -E "\<MP_PLUGIN_ULTRAPATH\>" | grep -E -c "\<vendor=${thisVendor}[, ]*model=${thisModel}\>"` -gt 0 ]
            then
                exit 1
            fi
        fi
    done
    
    return 0
}

checkClaimrule()
{
    local claimrule_NumSet=""
    local claimrules_src=""
    local thisVendor=""
    local thisModel=""
    local claimRule_str=""
    executeCmdAndGetEcho "esxcli storage core claimrule list"
    claimRule_str="${GLOBAL_CMD_ECHO}"
    executeCmdAndGetEcho "cat /usr/libexec/jumpstart/plugins/psa-mp-plugin-ultrapath-rules.json"
    claimrules_src=`echo "${GLOBAL_CMD_ECHO}" |grep "storage core claimrule add"`
    claimrule_NumSet=`echo "${claimrules_src}"  |awk -F "--" '{print $3}' | awk '{print $2}'`
    for i in $claimrule_NumSet
    do
        thisVendor=`echo "${claimrules_src}" |grep -E "\<${i}\>" |awk -F "--" '{print $6}'|awk -F "=" '{print $2}'`
        thisVendor=`echo "${thisVendor}" | sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
        thisModel=`echo "${claimrules_src}" |grep -E "\<${i}\>" |awk -F "--" '{print $7}'|awk -F "=" '{print $2}'`
        thisModel=`echo "${thisModel}" | sed 's/\",//g' | sed 's/\\\"//g' |sed 's/^[ \t]*//g' | sed 's/[ \t]*$//g'`
        if [ `echo "${claimRule_str}" | grep "runtime"| grep -E "\<MP_PLUGIN_ULTRAPATH\>"| grep "$i" | grep -E -c "\<vendor=${thisVendor}[, ]*model=${thisModel}\>"` -eq 0 ]
        then
            return 1
        fi
    done
    return 0
}

errorParam()
{
    exit 2
}

if [ ! -z $1 ]
then
    case $1 in
        -d)
            checkRedundantDisk
            ;;
        -c)
            checkClaimrule
            ;;
        *)
            errorParam
            ;;
    esac
fi
